@@ -1,7 +1,9 @@
 pub mod handler;
 
+use crate::image::ImageMode;
+
 #[derive(Debug, Clone)]
 pub enum IoEvent {
-    Initialize,
+    Initialize(ImageMode),
     LoadImage,
 }
